@@ -6,18 +6,18 @@ import pytest
 from flask import Flask
 
 
-@pytest.fixture(scope='function')
-def app():
-    """Create an instance of a Flask app."""
-    app = Flask(__name__)
-    return app
-
-
 @pytest.fixture
 def config():
     """Create a configuration class which can be loaded by a Flask app."""
     class Config:
         GCM_KEY = 'super secret'
-        GCM_URL = 'gcm url'
-        GCM_PROXY = 'gcm proxy'
+        GCM_URL = 'http://foobar.com'
     return Config
+
+
+@pytest.fixture(scope='function')
+def app(config):
+    """Create an instance of a Flask app."""
+    app = Flask(__name__)
+    app.config.from_object(config)
+    return app
